============
Covid Vision
============


.. image:: https://img.shields.io/pypi/v/covid_vision.svg
        :target: https://pypi.python.org/pypi/covid_vision

.. image:: https://img.shields.io/travis/edsoncavalcanti/covid_vision.svg
        :target: https://travis-ci.com/edsoncavalcanti/covid_vision

.. image:: https://readthedocs.org/projects/covid-vision/badge/?version=latest
        :target: https://covid-vision.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




This project aims to develop Computer Vision algorithms to help the detection of COVID-19 virus on images.


* Free software: MIT license
* Documentation: https://covid-vision.readthedocs.io.

Install the project
-------------------

`python setup.py install`

Features
--------

- DataLoader: Load the images dataset for the user.
- CovidCXR: Download CovidCXR model and predict one image


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
